/**
 *
 * Openutils testing library (http://www.openmindlab.com/products/testing.html)
 *
 * Copyright(C) 2005-2013, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package it.openutils.testing;

import java.text.MessageFormat;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.commons.lang3.StringUtils;


/**
 * @author gcatania
 */
public class AssertFormatter
{

    protected AssertFormatter()
    {
    }

    /**
     * internal utility method to print a more accurate description of objects in error messages
     * @param o the objec
     * @return the object's type name
     */
    protected static final String typeName(Object o)
    {
        if (o != null)
        {
            if (o instanceof Set< ? >)
            {
                return "set";
            }
            if (o instanceof List< ? >)
            {
                return "list";
            }
            if (o instanceof Collection< ? >)
            {
                return "collection";
            }
            if (o instanceof Map< ? , ? >)
            {
                return "map";
            }
        }
        return "object";
    }

    /**
     * same as {@code typeName()}, but with capitalization
     * @param o the object
     * @return the capitalized type name
     */
    protected static final String capitalizedTypeName(Object o)
    {
        return StringUtils.capitalize(typeName(o));
    }

    /**
     * bulds an error message by formatting a builtin error message with the input parameters and prepending it with an
     * input error message, if present.
     * @param inputMessage the input message
     * @param builtinMessage the builtin message
     * @param params the parameters to be formatted in the builtin message
     * @return the formatted message
     */
    protected static String buildMessage(String inputMessage, String builtinMessage, Object... params)
    {
        String formatted = MessageFormat.format(builtinMessage, params);
        if (StringUtils.isNotEmpty(inputMessage))
        {
            formatted = inputMessage + " " + formatted;
        }
        return formatted;
    }

    /**
     * builds an assertion error with the message determined by a call to
     * {@link #buildMessage(String, String, Object...)} with the input parameters
     * @param inputMessage the input message
     * @param builtinMessage the builtin message
     * @param params the parameters to be formatted in the builtin message
     * @return an assertion error with the formatted message
     */
    protected static AssertionError assertionFailed(String inputMessage, String builtinMessage, Object... params)
    {
        return new AssertionError(buildMessage(inputMessage, builtinMessage, params));
    }

}
