/**
 *
 * Openutils testing library (http://www.openmindlab.com/products/testing.html)
 *
 * Copyright(C) 2005-2013, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package it.openutils.testing.collections;

import it.openutils.testing.AssertFormatter;

import java.util.List;


/**
 * @author gcatania
 */
public class ListAssert extends AssertFormatter
{

    protected ListAssert()
    {
    }

    /**
     * Asserts that two lists are equal in both number and order of elements.
     * @param actual the actual list
     * @param expected the expected list
     * @param message a custom message
     * @throws AssertionError if assertion fails
     */
    public static void assertEquals(List< ? > actual, List< ? > expected, String message) throws AssertionError
    {
        if (expected == null)
        {
            CollectionAssert.assertNull(actual, message);
        }
        else if (expected.isEmpty())
        {
            CollectionAssert.assertEmpty(actual, message);
        }
        else
        {
            int expectedSize = expected.size();
            CollectionAssert.assertSizeEquals(actual, expectedSize, message);
            for (int y = 0; y < expectedSize; y++)
            {
                Object e = expected.get(y);
                Object a = actual.get(y);
                if ((e != null && !e.equals(a)) || (e == null && a != null))
                {
                    throw assertionFailed(message, "At position {0}: expected {1}, found {2} instead.", y, e, a); // yea!
                }
            }
        }
    }

    /**
     * Asserts that two lists are equal in both number and order of elements.
     * @param actual the actual list
     * @param expected the expected list
     * @throws AssertionError if assertion fails
     */
    public static void assertEquals(List< ? > actual, List< ? > expected) throws AssertionError
    {
        assertEquals(actual, expected, null);
    }

}
