/**
 *
 * Openutils testing library (http://www.openmindlab.com/products/testing.html)
 *
 * Copyright(C) 2005-2013, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package it.openutils.testing.collections;

import it.openutils.testing.AssertFormatter;

import java.util.Set;


/**
 * @author gcatania
 */
public class SetAssert extends AssertFormatter
{

    protected SetAssert()
    {
    }

    /**
     * Asserts that two sets are equal, regardless of element order.
     * @param actual the actual set
     * @param expected the expected set
     * @param message a custom error message
     * @throws AssertionError if assertion fails
     */
    public static void assertEquals(Set< ? > actual, Set< ? > expected, String message) throws AssertionError
    {
        if (expected == null)
        {
            CollectionAssert.assertNull(actual, message);
        }
        else if (expected.isEmpty())
        {
            CollectionAssert.assertEmpty(actual, message);
        }
        else
        {
            CollectionAssert.assertSizeEquals(actual, expected.size(), message);
            for (Object o : expected)
            {
                if (!actual.contains(o))
                {
                    throw assertionFailed(message, "Element {0} not found in {1}.", o, typeName(actual));
                }
            }
        }
    }

    /**
     * Asserts that two sets are equal, regardless of element order.
     * @param actual the actual set
     * @param expected the expected set
     * @throws AssertionError if assertion fails
     */
    public static void assertEquals(Set< ? > actual, Set< ? > expected) throws AssertionError
    {
        assertEquals(actual, expected, null);
    }
}
